SystemOrganization addCategory: #VolunteerMPlace!

TestCase subclass: #BrunoTest
	instanceVariableNames: 'coordinator project task coordStream'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!BrunoTest methodsFor: 'running' stamp: 'BBC 10/3/2012 22:48'!
setUp
	"set up test environment"
	
	coordinator := Coordinator new.
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP'.
				
	project := VolunteerProject new.	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes'. 	
			
	task := Task new.	
	task name: 'Give Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40. ! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 21:22'!
testCreatingCoordinator
	"comment stating purpose of message"

	| fileName fileStream|
	
	coordinator name: 'Bruno' ;
				 email: 'collaco.bruno@gmail.com' ;
				 organization: 'IAG-USP' ;
				 save.

	
	fileName := '/Users/bruno/Desktop/Volunteers/', (coordinator name), '.txt'.
	fileStream := FileStream fileNamed: fileName.
	
	self deny: (fileStream = nil).

				
				
	! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 20:42'!
testCreatingProject
	"comment stating purpose of message"
	
	| fileName fileStream|
	
	project name: 'Weekend Classes' ;
		      description: 'This project aims to help students by giving extra classes on the weekends' ;
		      type: 'Extra Classes' ;
		      save. 

	fileName := '/Users/bruno/Desktop/Volunteers/', (project name), '.txt'.
	fileStream := FileStream fileNamed: fileName.
	
	self deny: (fileStream = nil).! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 21:28'!
testCreatingTask
	"comment stating purpose of message"
	
	| fileName fileStream|
	
	task name: 'Give Classes' ;
		  description: 'to give classes at weekends...' ;
		  endDate: '2012-12-1' ;
              estimatedTime: 40 ; 
		  save. 

	fileName := '/Users/bruno/Desktop/Volunteers/', (task name), '.txt'.
	fileStream := FileStream fileNamed: fileName.
	
	self deny: (fileStream = nil).! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 23:50'!
testDependeces
	"comment stating purpose of message"
	
	| firstTask|
	
	firstTask := Task new.
	firstTask name: 'Needed Task'.
	
	task dependsOn: firstTask.
	
	self assert: ((task status) = 'Frozen').
! !

!BrunoTest methodsFor: 'creating' stamp: 'BBC 10/3/2012 23:03'!
testzCoordProjTask
	"comment stating purpose of message"
	
	| coordFile coordStream volunteerFile volunteerStream taskFile taskStream |
	
	coordinator addCoordinatedProject: project.
	
	project addCoordinator: coordinator ;
	            addTask: task.
	
	task addSkill: 'teaching' ;
		 addVolunteer: 'Isaac Newton'.

	coordinator save.
	project save.
	task save.
	
	coordFile := '/Users/bruno/Desktop/Volunteers/', (coordinator name), '.txt'.
	coordStream := FileStream fileNamed: coordFile.
	volunteerFile := '/Users/bruno/Desktop/Volunteers/', (project name), '.txt'.
	volunteerStream := FileStream fileNamed: volunteerFile.
	taskFile := '/Users/bruno/Desktop/Volunteers/', (task name), '.txt'.
	taskStream := FileStream fileNamed: taskFile.
	
	self deny: (coordStream = nil & volunteerStream = nil & taskStream = nil).! !

TestCase subclass: #TestProject
	instanceVariableNames: 'aUser aCoordinator'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!TestProject methodsFor: 'running' stamp: 'RG 10/14/2012 14:18'!
setUp
	aUser  := User new.
	aUser name: 'Mijail222'.
	aUser login: 'exmija'.
	aUser password: '1234'.
	
	aCoordinator := Coordinator new.
	aCoordinator name: 'Renzo222'.
	aCoordinator login: 'rgomez'.
	aCoordinator password: '12345'.

	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/13/2012 21:45'!
testAddCoordinator
	"comment stating purpose of message"
	| project |
	project := ProjectX new.
	project name: 'Test Project 2'.
	project setCoordinator: aUser.
	project save.
	self assert: ( project isCoordinator: aUser ).
	self assert: ( ( project isCoordinator: aCoordinator ) = false). 
	( OperationValidator modifyProject: project user: aUser ) ifTrue: [
		project addCoordinator: aCoordinator.
	].
	self assert: ( project isCoordinator: aCoordinator ).! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/13/2012 23:25'!
testAddTask
	"comment stating purpose of message"
	| project aTask instance |
	project := ProjectX new.
	project name: 'Test Project 3'.
	self assert: (( project isCoordinator: aUser ) = false)..
	project setCoordinator: aUser.
	project save.
	self assert: ( project isCoordinator: aUser ).
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	self assert: (instance hasObject: aTask).
	( OperationValidator modifyProject: project user: aUser ) ifTrue: [
		project addTask: aTask.
	].
	self assert: ( (project tasks) includes: aTask ).! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/13/2012 23:34'!
testAddTaskFailure
	"comment stating purpose of message"
	| project aTask instance |
	project := ProjectX new.
	project name: 'Test Project 3'.
	self assert: (( project isCoordinator: aUser ) = false)..
	project save.
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	self assert: (instance hasObject: aTask).
	self assert: ( (OperationValidator modifyProject: project user: aUser) = false ).! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/14/2012 00:14'!
testAdminAddTask
	| project aTask instance anAdmin |
	project := ProjectX new.
	project name: 'Test Project 3'.
	
	anAdmin := Admin new.
	anAdmin setFromUser: aUser. 
	anAdmin save.
	instance := AdminCollection default.
	self assert: (instance hasObject: anAdmin).
	project save.
	self assert: (( project isCoordinator: aUser ) = false)..
	aTask := Task new.
	aTask name: 'Task 1'.
	aTask save.
	instance := TaskCollection default.
	self assert: (instance hasObject: aTask).
	( OperationValidator modifyProject: project user: aUser ) ifTrue: [
		project addTask: aTask.
	].
	self assert: ( (project tasks) includes: aTask ).! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/12/2012 23:06'!
testProjectXCreation
	| project instanceProject instanceCoordinator |
	project := ProjectX new.
	project name: 'Test project'.
	project setCoordinator: aUser.
	project save.
	instanceProject := ProjectCollection default.
	instanceCoordinator := CoordinatorCollection default.
	self assert: ( instanceProject hasObject: project ).
	self assert: ( instanceCoordinator hasObject: aUser).! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/14/2012 17:24'!
testRemoveTaskAdmin
	| project aTask anAdmin |
	
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.
	
	project := ProjectX new.
	project name: 'Test Project 5'.
	project save.
	anAdmin := Admin new.
	anAdmin setFromUser: aUser.
	anAdmin save.
	
	self assert: (( project isCoordinator: aUser ) = false).
	aTask := Task new.
	aTask name: 'Task 3'.
	project addTask: aTask.
	( OperationValidator modifyProject: project user: aUser ) ifTrue: [
		project removeTask: aTask.
	].
	self assert: ( ((project tasks) includes: aTask) = false).
! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/14/2012 17:05'!
testRemoveTaskCoordinator
	| project aTask |
	project := ProjectX new.
	project name: 'Test Project 4'.
	project setCoordinator: aUser.
	project save.
	self assert: ( project isCoordinator: aUser ).
	aTask := Task new.
	aTask name: 'Task 2'.
	project addTask: aTask.
	( OperationValidator modifyProject: project user: aUser ) ifTrue: [
		project removeTask: aTask.
	].
	self assert: ( ((project tasks) includes: aTask) = false).! !

!TestProject methodsFor: 'testing' stamp: 'RG 10/14/2012 17:27'!
testRemoveTaskFailure
	| project aTask |
	
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.
	
	project := ProjectX new.
	project name: 'Test Project 5'.
	project save.
	self assert: (( project isCoordinator: aUser ) = false).
	aTask := Task new.
	aTask name: 'Task 3'.
	project addTask: aTask.
	( OperationValidator modifyProject: project user: aUser ) ifTrue: [
		project removeTask: aTask.
	].
	self assert: ((project tasks) includes: aTask).
! !

TestCase subclass: #TestSkill
	instanceVariableNames: 'aUser aSkill'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!TestSkill methodsFor: 'running' stamp: 'RG 10/14/2012 14:18'!
setUp
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.

	aUser  := User new.
	aUser name: 'Mijail11'.
	aUser login: 'exmija'.
	aUser password: '1234'.
	
	aSkill := Skill new.
	aSkill name: 'Test Skill'.
	aSkill description: 'Test'.! !

!TestSkill methodsFor: 'testing' stamp: 'RG 10/13/2012 00:27'!
testCreateSkill
	| instance |
	instance := SkillCollection default.
	self assert: (( OperationValidator addSkill: aUser ) = false).
	self assert: ((instance hasObject: aSkill) = false).
	instance := AdminCollection default.
	instance addAdmin: aUser.
	self assert: (OperationValidator addSkill: aUser ).
	aSkill save.
	instance := SkillCollection default.
	self assert: (instance hasObject: aSkill)! !

TestCase subclass: #TestTask
	instanceVariableNames: 'aProject aCoordinator aTask'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!TestTask methodsFor: 'running' stamp: 'RG 10/14/2012 18:49'!
setUp
	ProjectCollection reset.
	TaskCollection reset.
	AdminCollection reset.
	CoordinatorCollection reset.
	SkillCollection reset. 
	
	aCoordinator := Coordinator new.
	aCoordinator name: 'Test Coordinator'.
	
	aProject := ProjectX new.
	aProject name: 'Test Project 5'.

	aTask := Task new.
	aTask name: 'Test Task'.
	
	aProject addCoordinator: aCoordinator.
	aProject addTask: aTask.
		
	
! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/14/2012 18:56'!
testAddSkillCoordinator
	| aSkill |
	
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	
	self assert: ((aProject tasks) includes: aTask).
	self assert: (( aTask hasSkill: aSkill ) = false).
	
	( OperationValidator modifyProject: aProject user: aCoordinator ) ifTrue: [
		aTask addSkill: aSkill.		
	].
	self assert: ( aTask hasSkill: aSkill ).
! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/14/2012 19:01'!
testRemoveSkillAdmin
	| aSkill anAdmin |
	
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.	
	self assert: ( aTask hasSkill: aSkill ).
	
	anAdmin := Admin new.
	anAdmin name: 'Test Admin'.
	anAdmin save.
	
	( OperationValidator modifyProject: aProject user: anAdmin ) ifTrue: [
		aTask removeSkill: aSkill.
	].
	self assert: (( aTask hasSkill: aSkill ) = false).
	
	AdminCollection reset.! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/14/2012 18:59'!
testRemoveSkillCoordinator
	| aSkill |
	
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.	
	self assert: ( aTask hasSkill: aSkill ).
	
	( OperationValidator modifyProject: aProject user: aCoordinator ) ifTrue: [
		aTask removeSkill: aSkill.
	].
	self assert: (( aTask hasSkill: aSkill ) = false).
	
! !

!TestTask methodsFor: 'testing' stamp: 'RG 10/14/2012 19:03'!
testRemoveSkillFailure
	| aSkill aUser |
	
	aSkill := Skill new.
	aSkill name: 'PHP Programming'.
	aSkill description: 'Knows to program in PHP'.
	aTask addSkill: aSkill.	
	self assert: ( aTask hasSkill: aSkill ).
	
	aUser := User new.
	aUser name: 'Test User'.
	
	( OperationValidator modifyProject: aProject user: aUser ) ifTrue: [
		aTask removeSkill: aSkill.
	].

	self assert: (( aTask hasSkill: aSkill )).! !

TestCase subclass: #TestUser
	instanceVariableNames: 'project user'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!TestUser methodsFor: 'running' stamp: 'RG 10/14/2012 14:17'!
setUp
	VolunteerCollection reset.
	ProjectCollection reset.
	AdminCollection reset.
	TaskCollection reset.
	SkillCollection reset.
	Comment reset.
	
	project := ProjectX new.
	project name: 'Test Project 4'.
	project save.
	
	user := User new.
	user name: 'Renzo333'.
	user login: 'rgomez'.
	user password: '1234'.! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/14/2012 12:13'!
testAddComment
	"comment stating purpose of message"
	| aComment |
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	self assert: (( project comments ) includes: aComment).
! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/14/2012 14:14'!
testCreateUser
	"Test user creation"
	| aUser volunteer instance |
	aUser  := User new.
	aUser name: 'Foo'.
	aUser login: 'bar'.
	aUser password: '1234'.
	volunteer := Volunteer new.
	volunteer setFromUser: aUser.
	volunteer save.
	instance := VolunteerCollection default.
	self assert: ( instance hasObject: volunteer ).! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/14/2012 14:14'!
testRemoveCommentAdmin
	"comment stating purpose of message"
	| anAdmin aComment |
	"Create a Coordinator"
	anAdmin := Admin new.
	anAdmin name: 'Test'.
	anAdmin login: 'test'.
	anAdmin password: '12345'.
	anAdmin save.
	"Create dummy comment"
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing creation of comment"
	self assert: (( project comments ) includes: aComment).
	"Testing if anAdmin can remove"
	(OperationValidator modifyComment: aComment project: project user: anAdmin) ifTrue: [
		project removeComment: aComment.	
	].
	"Test if the operation was successful"
	self assert: ( (( project comments ) includes: aComment) = false).! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/14/2012 14:13'!
testRemoveCommentCoordinator
	"comment stating purpose of message"
	| aCoordinator aComment |
	"Create a Coordinator"
	aCoordinator := Coordinator new.
	aCoordinator name: 'Brunp'.
	aCoordinator login: 'bruno'.
	aCoordinator password: '12345'.
	"Add Coordinator to project"
	project addCoordinator: aCoordinator.
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing creation of comment"
	self assert: (( project comments ) includes: aComment).
	"Testing if aCoordinator can remove"
	(OperationValidator modifyComment: aComment project: project user: aCoordinator) ifTrue: [
		project removeComment: aComment.	
	].
	"Test if the operation was successful"
	self assert: ( (( project comments ) includes: aComment) = false).! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/14/2012 14:10'!
testRemoveCommentFailure
	"comment stating purpose of message"
	| aUser aComment |
	"Create a Coordinator"
	aUser := User new.
	aUser name: 'Mijail'.
	aUser login: 'mija'.
	aUser password: '12345'.
	"Create dummy comment"
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing creation of comment"
	self assert: (( project comments ) includes: aComment).
	"Testing if anAdmin can remove"
	(OperationValidator modifyComment: aComment project: project user: aUser) ifTrue: [
		project removeComment: aComment.
		Transcript show: 'IN'.
	].
	"Test if the comment was not removed"
	self assert: ( (( project comments ) includes: aComment)).! !

!TestUser methodsFor: 'testing' stamp: 'RG 10/14/2012 13:34'!
testRemoveCommentUser
	"Test comment removement from creator"
	| aComment |
	aComment := Comment new.
	aComment user: user.
	project addComment: aComment.
	"Testing creation of comment"
	self assert: (( project comments ) includes: aComment).
	"Testing if user can remove"
	(OperationValidator modifyComment: aComment project: project user: user) ifTrue: [
		project removeComment: aComment.	
	].
	"Test if the operation was successful"
	self assert: ( (( project comments ) includes: aComment) = false).
	
	! !

Object subclass: #CollectionSingleton
	instanceVariableNames: 'list'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

CollectionSingleton class
	instanceVariableNames: 'soleInstance'!

!CollectionSingleton commentStamp: 'RG 10/6/2012 15:04' prior: 0!
Singleton of a collection of objects!

CollectionSingleton class
	instanceVariableNames: 'soleInstance'!

CollectionSingleton subclass: #AdminCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!AdminCollection methodsFor: 'as yet unclassified' stamp: 'RG 10/12/2012 20:51'!
addAdmin: anAdmin	
	| result |
	result := (super add: anAdmin).
	(result) ifTrue: [ Transcript cr ; show: (anAdmin name), ' added as Admin'. ].! !

!AdminCollection methodsFor: 'as yet unclassified' stamp: 'RG 10/12/2012 20:53'!
removeAdmin: anAdmin
	"removes an admin from the collection"
	| result |
	result := super remove: anAdmin.
	(result) ifTrue: [ Transcript cr ; show: (anAdmin name), ' removed from Admins'. ].! !

!CollectionSingleton class methodsFor: 'as yet unclassified' stamp: 'RG 10/6/2012 15:07'!
default
	"Get the unique instance"

	(soleInstance isNil) ifTrue: [soleInstance := self basicNew initialize].
	^ soleInstance! !

!CollectionSingleton class methodsFor: 'as yet unclassified' stamp: 'RG 10/6/2012 15:06'!
new
	"comment stating purpose of message"

	self error: 'Cannot create a new instance.'! !

!CollectionSingleton class methodsFor: 'as yet unclassified' stamp: 'RG 10/6/2012 15:07'!
reset
	"Reset the unique instance to nil"

	soleInstance := nil.! !

!CollectionSingleton methodsFor: 'editing' stamp: 'RG 10/6/2012 15:16'!
add: anObject
	"Adds an element to the collection
	 returns true or false depending on the outcome of the operation."
	[ list add: anObject. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!CollectionSingleton methodsFor: 'gets' stamp: 'RG 10/6/2012 16:08'!
collection
	"Return the collection of objects in the system"
	^list.! !

!CollectionSingleton methodsFor: 'as yet unclassified' stamp: 'RG 10/12/2012 20:25'!
getObject: anObject
	| index |
	index := list indexOf: anObject ifAbsent: [ 0. ].
	(index > 0) ifTrue: [ ^list at: index. ].
	^nil.! !

!CollectionSingleton methodsFor: 'as yet unclassified' stamp: 'RG 10/12/2012 19:45'!
hasObject: anObject
	"Returns if an object is in the collection"
	| index |
	index := list indexOf: anObject ifAbsent: [ 0 ].
	^ ( index > 0 ).
	! !

!CollectionSingleton methodsFor: 'initialize-release' stamp: 'RG 10/6/2012 15:11'!
initialize
	"Initialize the list of objects"
	list := OrderedCollection new.! !

!CollectionSingleton methodsFor: 'editing' stamp: 'RG 10/6/2012 15:15'!
remove: anObject
	"remove a collection from the list
	 returns true or false depending on the outcome of the operation."
	| index |
	[index := (list find: anObject).
	(index isNil) ifFalse: [list removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!CollectionSingleton methodsFor: 'editing' stamp: 'RG 10/6/2012 15:19'!
update: anObject
	"Updates an element of the collection
	 returns true or false depending on the outcome of the operation."
	| result |
	result := self remove: anObject.
	(result) ifTrue: [
		result := self add: anObject.	
	].
	^result.! !

CollectionSingleton subclass: #CoordinatorCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!CoordinatorCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:57'!
addCoordinator: aCoordinator
	"Adds a coordinator in the collection"
	
	| result |
	
	result := (super add: aCoordinator).
	(result) ifTrue: [ Transcript cr ; show: (aCoordinator name), ' added as Coordinator'. ].! !

!CoordinatorCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:57'!
removeCoordinator: aCoordinator
	"removes a coordinator from the collection"
	
	| result |
	
	result := super remove: aCoordinator.
	(result) ifTrue: [ Transcript cr ; show: (aCoordinator name), ' removed from Coordinators'. ].! !

!CoordinatorCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:38'!
updateCoordinator: aCoordinator
	"Updates a coordinator from the collection"
	
	| result |
	
	result := super update: aCoordinator.
	( result ) ifTrue: [ Transcript cr ; show: (aCoordinator name), ' updated'.  ]! !

CollectionSingleton subclass: #ProjectCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!ProjectCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:01'!
addProject: aProject
	"Adds a project in the collection"
	
	| result |
	
	result := (super add: aProject).
	(result) ifTrue: [ Transcript cr ; show: (aProject name), ' added in Projects'. ].! !

!ProjectCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:02'!
removeProject: aProject
	"removes a project from the collection"
	
	| result |
	
	result := super remove: aProject.
	(result) ifTrue: [ Transcript cr ; show: (aProject name), ' removed from Projects'. ].! !

!ProjectCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:04'!
updateProject: aProject
	"Updates a project from the collection"
	
	| result |
	
	result := super update: aProject.
	( result ) ifTrue: [ Transcript cr ; show: (aProject name), ' updated'.  ]! !

CollectionSingleton subclass: #SkillCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!SkillCollection commentStamp: 'RG 10/6/2012 15:21' prior: 0!
Collection of Skills of the system!

!SkillCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 14:38'!
addSkill: aSkill
	"Add a skill in the collection"
	| result |
	result := (super add: aSkill).
	(result) ifTrue: [ Transcript cr ; show: (aSkill name), ' added in Skills'. ].! !

!SkillCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:28'!
removeSkill: aSkill
	"removes a skill from the collection"
	| result |
	result := super remove: aSkill.
	(result) ifTrue: [ Transcript cr ; show: (aSkill name), ' removed from Skills'. ].

	! !

!SkillCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:30'!
updateSkill: aSkill
	"Updates a skill from the collection"
	| result |
	result := super update: aSkill.
	( result ) ifTrue: [ Transcript cr ; show: (aSkill name), ' updated'.  ]! !

CollectionSingleton subclass: #TaskCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 14:39'!
addTask: aTask
	"Add a task in the collection"
	| result |
	result := (super add: aTask).
	(result) ifTrue: [ Transcript cr ; show: (aTask name), ' added in Tasks'. ].! !

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 14:38'!
removeTask: aTask
	"removes a task from the collection"
	| result |
	result := super remove: aTask.
	(result) ifTrue: [ Transcript cr ; show: (aTask name), ' removed from Tasks'. ].! !

!TaskCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 16:30'!
updateTask: aTask
	"Updates a task from the collection"
	
	| result |
	
	result := super update: aTask.
	( result ) ifTrue: [ Transcript cr ; show: (aTask name), ' updated'.  ]! !

CollectionSingleton subclass: #VolunteerCollection
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!VolunteerCollection commentStamp: 'RG 10/6/2012 15:44' prior: 0!
A collection of volunteers of the system.!

!VolunteerCollection methodsFor: 'editing' stamp: 'BBC 10/8/2012 15:58'!
addVolunteer: aVolunteer
	"Add a volunteer in the collection"
	| result |
	result := (super add: aVolunteer).
	(result) ifTrue: [ Transcript cr ; show: (aVolunteer name), ' added as Volunteer'. ].! !

!VolunteerCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:46'!
removeVolunteer: aVolunteer
	"removes a volunteer from the collection"
	| result |
	result := super remove: aVolunteer.
	(result) ifTrue: [ Transcript cr ; show: (aVolunteer name), ' removed from Volunteers'. ].! !

!VolunteerCollection methodsFor: 'editing' stamp: 'RG 10/6/2012 15:48'!
updateVolunteer: aVolunteer
	"Updates a skill from the collection"
	| result |
	result := super update: aVolunteer.
	( result ) ifTrue: [ Transcript cr ; show: (aVolunteer name), ' updated'.  ]! !

Object subclass: #Comment
	instanceVariableNames: 'id user message date'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

Comment class
	instanceVariableNames: 'counter'!

!Comment commentStamp: 'RG 10/8/2012 15:04' prior: 0!
Represents a user commentary!

Comment class
	instanceVariableNames: 'counter'!

!Comment class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 11:45'!
counter
	| temp |
	(counter isNil) ifTrue: [ counter := 1. ].
	temp := counter.
	counter := counter + 1.
	^temp.! !

!Comment class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 13:35'!
reset
	"Resets counter of instances"
	counter := 1.! !

!Comment methodsFor: 'comparing' stamp: 'RG 10/14/2012 11:47'!
= aComment
	^ (id = aComment id)! !

!Comment methodsFor: 'gets' stamp: 'RG 10/8/2012 15:09'!
date
	"gets the date of creation of the comment"
	^date.! !

!Comment methodsFor: 'sets' stamp: 'RG 10/8/2012 15:09'!
date: aDate
	"sets the date of the comment"
	date := aDate.! !

!Comment methodsFor: 'gets' stamp: 'RG 10/14/2012 11:47'!
id
	^id.! !

!Comment methodsFor: 'initialize-release' stamp: 'RG 10/14/2012 11:43'!
initialize
	"Empty constructor"
	id := Comment counter.
	date := nil.
	user := nil.
	message := ''.! !

!Comment methodsFor: 'gets' stamp: 'RG 10/8/2012 15:07'!
message
	"gets the message of the comentary"
	^message! !

!Comment methodsFor: 'sets' stamp: 'RG 10/8/2012 15:08'!
message: aMessage
	"sets the message of the comment"
	message := aMessage.! !

!Comment methodsFor: 'gets' stamp: 'RG 10/8/2012 15:05'!
user
	"gets the user"
	^user! !

!Comment methodsFor: 'sets' stamp: 'RG 10/8/2012 15:06'!
user: aUser
	"sets a user"
	user := aUser! !

Object subclass: #LoginVerifier
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!LoginVerifier commentStamp: 'RG 10/8/2012 14:29' prior: 0!
Class that verifies the user login!

!LoginVerifier class methodsFor: 'operations' stamp: 'RG 10/8/2012 15:50'!
search: aListOfUsers login: aLogin password: aPassword
	"comment stating purpose of message"
	aListOfUsers do: [ :each |
			((each login = aLogin) and: (each password = aPassword))  ifTrue: [ ^each. ].
		].
	^nil.! !

!LoginVerifier class methodsFor: 'operations' stamp: 'RG 10/8/2012 15:42'!
verify: aLogin password: aPassword
	"Returns the user associated with the Login and Password"
	| instance list result |
	instance := VolunteerCollection default.
	list := instance collection.
	result := self search: list.
	( result isNil ) ifFalse: [ ^result. ]. 
	^nil.
	! !

Object subclass: #Offer
	instanceVariableNames: 'sender receiver message response accepted sentDate responseDate'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Offer commentStamp: 'MGH 10/8/2012 16:01' prior: 0!
This class represents an offer.!

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/8/2012 16:36'!
ResponseOffer: aAccepted message: aMessage
	"Send a offer to some user"
	response := aMessage.
	accepted := aAccepted.
	sender addOffer: self.
	responseDate := DateAndTime now.! !

!Offer methodsFor: 'as yet unclassified' stamp: 'MGH 10/8/2012 16:35'!
SendOffer: aSender receiver: aReceiver message: aMessage
	"Send a offer to some user"
	sender := aSender.
	receiver := aReceiver.
	message := aMessage.
	receiver addOffer: self.
	sentDate := DateAndTime now.! !

Object subclass: #OperationValidator
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 11:30'!
addSkill: aUser
	"return true if the user can add a skill,
	 false otherwise"
	^ self isAdmin: aUser.! !

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 11:28'!
isAdmin: aUser
	"Returns true if aUser is Admin"
	| instance |
	instance := AdminCollection default.
	^ instance hasObject: aUser ! !

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 14:05'!
modifyComment: aComment project: aProject user: aUser
	"Test if aUser can modify/remove a comment"
	( ( self isAdmin: aUser ) or: ( aProject isCoordinator: aUser ) ) ifTrue: [ ^true. ].
	^ ((aComment user) = aUser).! !

!OperationValidator class methodsFor: 'as yet unclassified' stamp: 'RG 10/13/2012 21:35'!
modifyProject: aProject user: aUser
	"A User can modify something from a project if is an admin or coodinator"
	| instance |
	instance := AdminCollection default.
	(( instance hasObject: aUser ) or: ( aProject isCoordinator: aUser )) ifTrue: [ ^true. ].
	^false.! !

Object subclass: #ProjectX
	instanceVariableNames: 'name type status description startDate endDate coordinators tasks comments'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!ProjectX methodsFor: 'comparing' stamp: 'BBC 10/8/2012 16:12'!
= aProject
	"answers if two projects are the same"

	^ (self name = aProject name)! !

!ProjectX methodsFor: 'sets' stamp: 'RG 10/14/2012 12:04'!
addComment: aComment
	comments add: aComment.! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:25'!
addCoordinator: aCoordinator
	"to add a coordinator to the Project"
	
	[ coordinators add: aCoordinator. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:26'!
addTask: aTask
	"to add a task to the Project"
	
	[ tasks add: aTask. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
! !

!ProjectX methodsFor: 'gets' stamp: 'RG 10/14/2012 12:03'!
comments
	^comments.! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:33'!
description
	"Answer the value of description"

	^ description! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:06'!
description: anObject
	"Set the value of description"

	description := anObject! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:33'!
endDate
	"Answer the value of endDate"

	^ endDate! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:34'!
endDate: aString
	"to set the value of endDate"
	
	endDate := aString asDate.! !

!ProjectX methodsFor: 'initialize-release' stamp: 'RG 10/14/2012 12:03'!
initialize
	"project constructor"
	
	super initialize.
	self name: ''.
	self description:''.
	self type:''.
	self status: 'Open.'.
	self startDate: Date today.
	self endDate: Date today.
	tasks := OrderedCollection new.
	coordinators := OrderedCollection new.
	comments := OrderedCollection new.

	! !

!ProjectX methodsFor: 'test' stamp: 'RG 10/12/2012 23:52'!
isCoordinator: aUser
	"returns true or false depending if the user is a coordinator"
	^ coordinators includes: aUser.! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:06'!
name: anObject
	"Set the value of name"

	name := anObject! !

!ProjectX methodsFor: 'persistence' stamp: 'BBC 10/8/2012 16:29'!
remove
	"remove the project from the system"
	
	| instance |
	
	instance := ProjectCollection default.
	instance removeProject: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!ProjectX methodsFor: 'sets' stamp: 'RG 10/14/2012 12:10'!
removeComment: aComment
	"to remove a coordinator from project"
	
	| index |
	index := comments indexOf: aComment ifAbsent: [ 0. ].
	( index > 0 ) ifTrue: [ comments removeAt: index. ].
! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:27'!
removeCoordinator: aCoordinator
	"to remove a coordinator from project"
	
	| index |
	
	[index := (coordinators find: aCoordinator).
	(index isNil) ifFalse: [coordinators removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:47'!
removeTask: aTask
	"to remove a task from project"
	
	| index |
	
	[index := (tasks find: aTask).
	(index isNil) ifFalse: [tasks removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
! !

!ProjectX methodsFor: 'persistence' stamp: 'BBC 10/8/2012 16:29'!
save
	"saves the project in the system"
	
	| projectInstance |
	
	projectInstance := ProjectCollection default.
	projectInstance addProject: self.
	Smalltalk snapshot: true andQuit: false.	! !

!ProjectX methodsFor: 'sets' stamp: 'RG 10/12/2012 20:30'!
setCoordinator: aUser
	"set the user of the project"
	| instance coordinator |
	coordinator := Coordinator new.
	coordinator setFromUser: aUser.
	instance := CoordinatorCollection default.
	( instance hasObject: coordinator ) ifTrue: [ coordinator := instance getObject: coordinator. ]
										ifFalse: [ coordinator save. ].
	self addCoordinator: coordinator.

	! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:33'!
startDate
	"Answer the value of startDate"

	^ startDate! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:35'!
startDate: aString
	"to set the value of startDate"
	
	startDate := aString asDate.! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:06'!
status
	"Answer the value of status"

	^ status! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:06'!
status: anObject
	"Set the value of status"

	status := anObject! !

!ProjectX methodsFor: 'sets' stamp: 'RG 10/13/2012 23:25'!
tasks
	^tasks.! !

!ProjectX methodsFor: 'gets' stamp: 'BBC 10/8/2012 16:06'!
type
	"Answer the value of type"

	^ type! !

!ProjectX methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:06'!
type: anObject
	"Set the value of type"

	type := anObject! !

!ProjectX methodsFor: 'persistence' stamp: 'BBC 10/8/2012 16:31'!
update
	"updates the information of the project from the system"
	
	| instance |
	
	instance := ProjectCollection default.
	instance updateProject: self.
	Smalltalk snapshot: true andQuit: false.	! !

Object subclass: #Skill
	instanceVariableNames: 'name description'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Skill commentStamp: 'RG 9/19/2012 20:57' prior: 0!
Represent a skill of a volunteer or needed in a task.!

!Skill methodsFor: 'comparing' stamp: 'BBC 10/8/2012 14:47'!
= aSkill
	"Testing Equality"
	
	^ ((self name) = (aSkill name)).! !

!Skill methodsFor: 'gets' stamp: 'RG 9/19/2012 21:00'!
description
	"Getter of description"
	^description.! !

!Skill methodsFor: 'sets' stamp: 'RG 9/19/2012 21:01'!
description: aDescription
	"Setter of description"
	description := aDescription.! !

!Skill methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 21:04'!
initialize
	"Empty constructor"
	super initialize.
	self name: ''.
	self description: ''.! !

!Skill methodsFor: 'initialize-release' stamp: 'RG 9/19/2012 21:06'!
initialize: aName desc: aDescription
	"Constructor with parameters"
	self name: aName.
	self description: aDescription.! !

!Skill methodsFor: 'gets' stamp: 'RG 9/19/2012 20:58'!
name
	"Getter of a name"
	^name.! !

!Skill methodsFor: 'sets' stamp: 'RG 9/19/2012 20:59'!
name: aName
	"Setter of name"
	name := aName.! !

!Skill methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:22'!
remove
	"remove the skill from the system"
	| instance |
	instance := SkillCollection default.
	instance removeSkill: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Skill methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:23'!
save
	"save the skill in the system"
	| skillInstance |
	skillInstance := SkillCollection default.
	skillInstance addSkill: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Skill methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:22'!
update
	"updates the information of the skill from the system"
	| instance |
	instance := SkillCollection default.
	instance updateSkill: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

Object subclass: #Task
	instanceVariableNames: 'name description status startDate endDate estimatedTime skills volunteers dependsOn'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Task commentStamp: 'BBC 10/2/2012 00:57' prior: 0!
stores a task!

!Task methodsFor: 'comparing' stamp: 'BBC 10/8/2012 14:48'!
= aTask
	"answers if two tasks are the same"

	^ (self name = aTask name)! !

!Task methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:23'!
addSkill: aSkill
	"to set the value of skills"
	
	[ skills add: aSkill. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!Task methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:23'!
addVolunteer: aVolunteer
	"to set the value of volunteers"
	
	[ volunteers add: aVolunteer. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 23:13'!
dependsOn
	"get task dependences"

	dependsOn do: [:task | Transcript cr; show: (task name) printString].
! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:55'!
dependsOn: aTask
	"to set task dependences"
	
	 
	dependsOn add: aTask.
	dependsOn do: [:task | ((task status) = 'Open') ifTrue: [self status: 'Frozen'] ].
	! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:29'!
description
	"get task description"

	^ description! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
description: aString
	"to set the value of description"
	
	description := aString.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:29'!
endDate
	"get task end date"

	^ endDate! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
endDate: aString
	"to set the value of endDate"
	
	endDate := aString asDate.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
estimatedTime
	"get task estimated time"

	^ estimatedTime! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
estimatedTime: anInteger
	"to set the value of estimatedTime, in hours"
	
	estimatedTime := anInteger.! !

!Task methodsFor: 'as yet unclassified' stamp: 'RG 10/6/2012 15:02'!
getListOfVolunteers: aListOfVolunteers
	"Sort the list of volunteers by the number of similarities of skills with the task"
	| list temp |
	list := OrderedCollection new.
	aListOfVolunteers do: [ :each | list add: (Association key: each value: (each numberOfSimilarities: skills) ). ].
	temp := list sort: [ :v1 :v2 | (v1 value) >= (v2 value). ].
	^temp collect: [ :each | each key. ].! !

!Task methodsFor: 'gets' stamp: 'BBC 10/5/2012 19:58'!
hasSkill: aSkill
	"Test if contains a skill"

	^(skills includes: aSkill).
! !

!Task methodsFor: 'initialize-release' stamp: 'RG 10/13/2012 23:29'!
initialize
	"task constructor"
	
	super initialize.
	self name: ''.
	self description: ''.
	self status: 'Open'.
	self startDate: Date today.
	self endDate: Date today.
	self estimatedTime: ''.
	dependsOn := OrderedCollection new.
	skills := OrderedCollection new.
	volunteers := OrderedCollection new.
	! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
name
	"get task name"

	^ name! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
name: aString
	"to set the value of name"
	
	name := aString.! !

!Task methodsFor: 'persistence' stamp: 'BBC 10/8/2012 14:59'!
remove
	"remove the task from the system"
	
	| instance |
	
	instance := TaskCollection default.
	instance removeTask: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Task methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:23'!
removeSkill: aSkill
	"to remove a skill from task"
	
	| index |
	
	[index := (skills find: aSkill).
	(index isNil) ifFalse: [skills removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
	! !

!Task methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:23'!
removeVolunteer: aVolunteer
	"to remove a volunteer from task"
	
	| index |
	
	[index := (volunteers find: aVolunteer).
	(index isNil) ifFalse: [skills removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
	! !

!Task methodsFor: 'persistence' stamp: 'BBC 10/8/2012 15:01'!
save
	"saves a task in the system"
	
	| taskInstance |
	
	taskInstance := TaskCollection default.
	taskInstance addTask: self.
	Smalltalk snapshot: true andQuit: false.	 
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
skills
	"get task skills"

	skills do: [:skill | Transcript cr; show: (skill name) printString].
! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
startDate
	"get task start date"

	^ startDate! !

!Task methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:34'!
startDate: aString
	"to set the value of startDate"
	
	startDate := aString asDate.! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
status
	"get task status"

	^ status! !

!Task methodsFor: 'sets' stamp: 'BBC 10/5/2012 19:56'!
status: aString
	"to set the value of status"
	
	status := aString.! !

!Task methodsFor: 'persistence' stamp: 'BBC 10/8/2012 15:00'!
update
	"updates the information of the task from the system"
	
	| instance |
	
	instance := TaskCollection default.
	instance updateTask: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Task methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:30'!
volunteers
	"get task volunteers"

	volunteers do: [:volunteer | Transcript cr; show: (volunteer name) printString].
! !

Object subclass: #User
	instanceVariableNames: 'login password name email photo inbox'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!User commentStamp: 'shout 10/2/2012 18:25' prior: 0!
User of the system!

User subclass: #Admin
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Admin commentStamp: 'shout 10/2/2012 18:33' prior: 0!
Admin of the system!

!Admin methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 00:11'!
= anAdmin
	"comment stating purpose of message"
	^(anAdmin name = name).! !

!Admin methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 00:13'!
save
	"save the admin in the system"
	| instance |
	instance := AdminCollection default.
	(instance hasObject: self) ifFalse: [ instance addAdmin: self. ].
	Smalltalk snapshot: true andQuit: false.	 ! !

!Admin methodsFor: 'as yet unclassified' stamp: 'RG 10/14/2012 00:08'!
setFromUser: aUser
	self name: (aUser name).
	self login: (aUser login).
	self password: (aUser password).
	self email: (aUser email).
	self inbox: (aUser inbox).! !

User subclass: #Coordinator
	instanceVariableNames: 'organization coordinatedProjects'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Coordinator commentStamp: 'BBC 9/22/2012 19:14' prior: 0!
stores a coordinator!

!Coordinator methodsFor: 'comparing' stamp: 'BBC 10/8/2012 15:13'!
= aCoordinator
	"answers if two coordinators are the same"

	^ (self name = aCoordinator name)! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:25'!
addCoordinatedProject: aProject
	"to add a project in coordinatedProjects"
	
	[ coordinatedProjects add: aProject. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.

! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
coordinatedProjects
	"get coordinator coordinated projects"

	coordinatedProjects do: [:project | Transcript cr; show: (project name) printString].! !

!Coordinator methodsFor: 'initialize-release' stamp: 'BBC 10/8/2012 15:44'!
initialize
	"coordinator constructor"
	
	super initialize.
	self name: ''.
	self organization:''.
	coordinatedProjects := OrderedCollection new.

	
! !

!Coordinator methodsFor: 'gets' stamp: 'BBC 10/3/2012 15:32'!
organization
	"get coordinator organization"

	^ organization! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/8/2012 15:07'!
organization: aString
	"coordinator's organization"
	
	organization := aString.! !

!Coordinator methodsFor: 'persistence' stamp: 'BBC 10/8/2012 15:39'!
remove
	"remove the coordinator from the system"
	
	| instance |
	
	instance := CoordinatorCollection default.
	instance removeCoordinator: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Coordinator methodsFor: 'sets' stamp: 'BBC 10/8/2012 16:23'!
removeCoordinatedProject: aProject
	"to remove a project from coordinatedProjects"
	
	| index |
	
	[index := (coordinatedProjects find: aProject).
	(index isNil) ifFalse: [coordinatedProjects removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.
	


! !

!Coordinator methodsFor: 'persistence' stamp: 'RG 10/12/2012 20:00'!
save
	"save the coordinator in the system"
	| coordinatorInstance |
	coordinatorInstance := CoordinatorCollection default.
	(coordinatorInstance hasObject: self) ifFalse: [ coordinatorInstance addCoordinator: self. ].
	Smalltalk snapshot: true andQuit: false.	 ! !

!Coordinator methodsFor: 'create/remove/edit' stamp: 'RG 10/12/2012 20:03'!
setFromUser: aUser
	self name: (aUser name).
	self login: (aUser login).
	self password: (aUser password).
	self email: (aUser email).
	self inbox: (aUser inbox).! !

!Coordinator methodsFor: 'persistence' stamp: 'BBC 10/8/2012 15:40'!
update
	"updates the information of the coordinator from the system"
	
	| instance |
	
	instance := CoordinatorCollection default.
	instance updateCoordinator: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!User methodsFor: 'comparing' stamp: 'RG 10/14/2012 14:03'!
= aUser
	^ (name = aUser name).! !

!User methodsFor: 'operation' stamp: 'MGH 10/8/2012 16:10'!
addOffer: message offer: aOffer
	"Add an offer into the inbox"
	[ inbox add: aOffer.]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!User methodsFor: 'gets' stamp: 'shout 10/7/2012 22:53'!
email
	"get user email"

	^ email! !

!User methodsFor: 'sets' stamp: 'RG 10/8/2012 14:21'!
email: aEmail
	"set email"
	email := aEmail.! !

!User methodsFor: 'gets' stamp: 'RG 10/12/2012 20:03'!
inbox
	^inbox.! !

!User methodsFor: 'sets' stamp: 'RG 10/12/2012 20:02'!
inbox: anInbox
	inbox := anInbox.! !

!User methodsFor: 'initialize-release' stamp: 'RG 10/12/2012 17:55'!
initialize
	"Empty constructor"
	login := ''.
	password := ''.
	email := ''.
	name := ''.
	inbox := OrderedCollection new.! !

!User methodsFor: 'gets' stamp: 'RG 10/8/2012 14:23'!
login
	^login.! !

!User methodsFor: 'sets' stamp: 'RG 10/8/2012 14:23'!
login: aLogin
	"sets login"
	login := aLogin! !

!User methodsFor: 'gets' stamp: 'shout 10/7/2012 22:50'!
name
	^name.! !

!User methodsFor: 'sets' stamp: 'shout 10/7/2012 22:50'!
name: aName
	"comment stating purpose of message"
	name := aName.! !

!User methodsFor: 'gets' stamp: 'RG 10/8/2012 14:25'!
password
	^password! !

!User methodsFor: 'sets' stamp: 'RG 10/8/2012 14:26'!
password: aPassword
	"sets password"
	password := aPassword.! !

!User methodsFor: 'operation' stamp: 'MGH 10/8/2012 16:24'!
responseOffer: message offer: aOffer accepted: aAccepted
	"Response an offer"
	| index |
	aOffer ResponseOffer: aAccepted message. 
	[index := (inbox find: aOffer).
	(index isNil) ifFalse: [inbox removeAt: index]. ]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!User methodsFor: 'gets' stamp: 'RG 10/12/2012 22:21'!
setFromUser: aUser
	"comment stating purpose of message"
	self login: (aUser login). 
	self password: (aUser password).
	self name: (aUser name). 
	self email: (aUser email).
	self inbox: (aUser inbox).! !

User subclass: #Volunteer
	instanceVariableNames: 'skills disponibility availability workTime finishedTasks finishedProjects birthday'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'VolunteerMPlace'!

!Volunteer commentStamp: 'RG 9/19/2012 21:15' prior: 0!
Represents a volunteer.!

!Volunteer methodsFor: 'comparing' stamp: 'BBC 10/8/2012 15:14'!
= aVolunteer
	"Comparing volunteers"
	
	^(self name = aVolunteer name)! !

!Volunteer methodsFor: 'operation' stamp: 'RG 10/1/2012 16:07'!
addSkill: aSkill
	"Add a skill to the volunteer"
	(self hasSkill: aSkill) ifFalse: [ skills add: aSkill. ]! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:41'!
availability
	"Getter availability"
	^availability.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:43'!
availability: anAvailability
	"Setter of availability"
	availability := anAvailability.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:37'!
birthday
	"Getter of birthday"
	^birthday.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:38'!
birthday: aBirthday
	"Setter of Birthday"
	birthday := aBirthday.! !

!Volunteer methodsFor: 'operation' stamp: 'shout 10/2/2012 21:46'!
createAccount: aLogin pass: aPwd name: aName email: aEmail photo: aPhoto skills: aSkills birthday: aBirthDay
	"Create an volunteer account"
	login := aLogin.
	password := aPwd.
	name := aName.
	email := aEmail.
	photo := aPhoto.
	skills := aSkills.
	disponibility := True.
	availability := True.
	workTime := 0.
	finishedTasks := 0.
	finishedProjects := 0.
	birthday := aBirthDay.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:39'!
disponibility
	"Getter of disponibility"
	^disponibility.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:41'!
disponibility: aDisponibility
	"Setter of disponibility"
	disponibility := aDisponibility.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:46'!
finishedProjects
	"Getter finishedProjects"
	^finishedProjects.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:47'!
finishedProjects: numberFinished
	"Setter finishedPrijects"
	finishedProjects := numberFinished.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:49'!
finishedTasks
	"Getter finishedTasks"
.	^finishedTasks.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:49'!
finishedTasks: numberFinished
	"Setter finished Tasks"
	finishedTasks := numberFinished.! !

!Volunteer methodsFor: 'operation' stamp: 'RG 10/1/2012 16:06'!
hasSkill: aSkill
	"Test if has an specific skill"
	^ (skills includes: aSkill).! !

!Volunteer methodsFor: 'initialize-release' stamp: 'RG 10/1/2012 14:13'!
initialize
	"Constructor"
	skills := OrderedCollection new.
	disponibility := ''.
	availability := false.
	workTime := ''.
	finishedTasks := 0.
	finishedProjects := 0.
	birthday := Date new.
	name := ''.! !

!Volunteer methodsFor: 'operation' stamp: 'RG 10/1/2012 16:05'!
numberOfSimilarities: aListOfSkills
	"Given a list of skills, gets the quantity of those that the volunteer posses"
	| count |
	count := 0.
	aListOfSkills do: [ :aSkill |
		( self hasSkill: aSkill ) ifTrue: [ count := count + 1. ].
	].
	^count.! !

!Volunteer methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:16'!
remove
	"remove the volunteer from the system"
	| instance |
	instance := VolunteerCollection default.
	instance removeVolunteer: self.
	Smalltalk snapshot: true andQuit: false.! !

!Volunteer methodsFor: 'operation' stamp: 'RG 10/8/2012 16:04'!
removeSkill: aSkill
	"remove a skill from the skills of the volunteer"
	"Returns true or false depending on the outcome of the operation"
	| index |
	[ index := (skills find: aSkill).
	  skills removeAt: index.]
	on: Exception
	do: [:ex | ^false. ].
	^true.! !

!Volunteer methodsFor: 'persistence' stamp: 'RG 10/6/2012 15:49'!
save
	"save the volunteer in the system"
	
	| volunteerInstance |
	
	volunteerInstance := VolunteerCollection default.
	volunteerInstance addVolunteer: self.
	Smalltalk snapshot: true andQuit: false.	 ! !

!Volunteer methodsFor: 'gets' stamp: 'RG 10/6/2012 15:53'!
skills
	"Return the list of skills"
	^skills! !

!Volunteer methodsFor: 'persistence' stamp: 'RG 10/6/2012 16:19'!
update
	"update the information of the volunteer from the system"
	| instance |
	instance := VolunteerCollection default.
	instance updateVolunteer: self.
	Smalltalk snapshot: true andQuit: false.! !

!Volunteer methodsFor: 'gets' stamp: 'RG 9/19/2012 21:44'!
workTime
	"Getter of worktime"
	^workTime.! !

!Volunteer methodsFor: 'sets' stamp: 'RG 9/19/2012 21:45'!
workTime: aWorkTime
	"comment stating purpose of message"
	workTime := aWorkTime.! !
